@@ -30,7 +30,7 @@ p0_check <- structure(list(x = c(1.95023867728441, 1.95023867728441), xend = c(3
 -2L))
 
 test_that("Check plotmod lm", {
-  expect_equal(layer_data(p0, 2)[, 2:5],
+  expect_equal(layer_data(p0, 2)[, colnames(p0_check)],
                p0_check)
   })
 
@@ -67,7 +67,7 @@ p0p_check <- structure(list(x = c(1.95023867728441, 1.95023867728441), xend = c(
 -2L))
 
 test_that("Check plotmod lm, percentiles", {
-  expect_equal(layer_data(p0p, 2)[, 2:5],
+  expect_equal(layer_data(p0p, 2)[, colnames(p0p_check)],
                p0p_check)
   })
 
@@ -122,7 +122,7 @@ p1_check <- structure(list(x = c(-1, -1), xend = c(1, 1), y = c(-0.2988884689495
 )), class = "data.frame", row.names = c(NA, -2L))
 
 test_that("Check plotmod lm, std", {
-  expect_equal(layer_data(p1, 2)[, 2:5],
+  expect_equal(layer_data(p1, 2)[, colnames(p1_check)],
                p1_check)
   })
 
@@ -159,7 +159,7 @@ p1p_check <- structure(list(x = c(-1, -1), xend = c(1, 1), y = c(-0.391907940837
 )), class = "data.frame", row.names = c(NA, -2L))
 
 test_that("Check plotmod lm, std, percentiles", {
-  expect_equal(layer_data(p1p, 2)[, 2:5],
+  expect_equal(layer_data(p1p, 2)[, colnames(p1p_check)],
                p1p_check)
   })
 
@@ -231,7 +231,7 @@ p0_wcat_check <- structure(list(x = c(1.95023867728441, 1.95023867728441), xend
 -2L))
 
 test_that("Check plotmod lm, std, percentiles", {
-  expect_equal(layer_data(p0_wcat, 2)[, 2:5],
+  expect_equal(layer_data(p0_wcat, 2)[, colnames(p0_wcat_check)],
                p0_wcat_check)
   })
 
@@ -354,7 +354,7 @@ p0_wcat_check <- structure(list(x = c(1.95023867728441, 1.95023867728441, 1.9502
 )), class = "data.frame", row.names = c(NA, -3L))
 
 test_that("Check plotmod lm, std, percentiles", {
-  expect_equal(layer_data(p0_wcat3, 2)[, 2:5],
+  expect_equal(layer_data(p0_wcat3, 2)[, colnames(p0_wcat_check)],
                p0_wcat_check)
   })
 
@@ -376,7 +376,7 @@ p1_wcat3_check <- structure(list(x = c(-1, -1, -1), xend = c(1, 1, 1), y = c(0.1
 -3L))
 
 test_that("Check plotmod lm, std, percentiles", {
-  expect_equal(layer_data(p1_wcat3, 2)[, 2:5],
+  expect_equal(layer_data(p1_wcat3, 2)[, colnames(p1_wcat3_check)],
                p1_wcat3_check)
   })
 
